<?php
declare(strict_types=1);

namespace CakeProducts\Controller;

use Cake\Core\Configure;
use Cake\Log\Log;
use Cake\ORM\Table;
use Cake\ORM\TableRegistry;
use CakeProducts\Controller\AppController;

/**
 * ProductCategoryAttributeOptions Controller
 *
 * @property \CakeProducts\Model\Table\ProductCategoryAttributeOptionsTable $ProductCategoryAttributeOptions
 */
class ProductCategoryAttributeOptionsController extends AppController
{
    /**
     * @var Table|null
     */
    protected ?Table $_table = null;

    /**
     * Gets the table instance
     *
     * @return Table
     */
    public function getTable()
    {
        if ($this->_table instanceof Table) {
            return $this->_table;
        }
        $this->_table = TableRegistry::getTableLocator()->get(
            Configure::read('CakeProducts.ProductCategoryAttributeOptions.table', 'CakeProducts.ProductCategoryAttributeOptions')
        );

        return $this->_table;
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        Log::debug('inside product category attribute options controller add');

        $productCategoryAttributeOption = $this->getTable()->newEmptyEntity();
        $this->set(compact('productCategoryAttributeOption'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Product Category Attribute Option id.
     * @return \Cake\Http\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $productCategoryAttributeOptionsTable = $this->getTable();

        $productCategoryAttributeOption = $productCategoryAttributeOptionsTable->get($id);
        if ($productCategoryAttributeOptionsTable->delete($productCategoryAttributeOption)) {
            $this->Flash->success(__('The product category attribute option has been deleted.'));
        } else {
            $this->Flash->error(__('The product category attribute option could not be deleted. Please, try again.'));
        }

        return $this->redirect(['controller' => 'ProductCategoryAttributes', 'action' => 'view', $productCategoryAttributeOption->product_category_attribute_id]);
    }
}
